@@ -84,7 +84,7 @@ char keyboard_default_translations[] = "\
 		SimulateKeyRelease(highlighted, unlessMod) \
 		UnhighlightKey(highlighted, unlessMod)	\n\
 \
-<Btn3Down>:	XawPositionSimpleMenu(keyMenu)		\
+Any<Btn3Down>:	XawPositionSimpleMenu(keyMenu)		\
 		MenuPopup(keyMenu)			\n\
 ";
 
