@@ -56,6 +56,12 @@
 # include <X11/HPkeysym.h>
 #endif
 
+#if defined(AIX) && !defined(ps2)
+# include <X11/aix_keysym.h>
+#endif
+
+#include "keysym-compat.h"
+
 #include "kbddef.h"
 
 
