@@ -402,7 +402,7 @@ button_write (button, client_data, call_data)
   KeySym *keysyms;
   int count, i, j, k;
   int partial = y_or_n_p (widget, "writeQuery", "full", "partial", "abort");
-  time_t now = time ((long *) 0);
+  time_t now = time ((time_t *) 0);
 #ifdef NO_PWD
   char *userid = 0;
 #else
