@@ -5,39 +5,6 @@
  * By Mick J Hellstrom <mickh@rd.scitec.com.au>              
  */
 
-/* Evidence suggests that Apollo makes a distinction between Page_Up and Prior
-   whereas other systems do not (they have the same numeric value.)  But, some
-   systems (notably SCO UnixWare 2) don't have the Page_Up alias for Prior.
-   So, we need this to be able to compile on those systems.
- */
-#ifndef XK_KP_Page_Up
-# define XK_KP_Page_Up XK_Prior
-#endif
-#ifndef XK_KP_Page_Down
-# define XK_KP_Page_Down XK_Next
-#endif
-#ifndef  XK_KP_Insert
-# define XK_KP_Insert	0xFF9E
-#endif
-#ifndef  XK_KP_Delete
-# define XK_KP_Delete	0xFF9F
-#endif
-#ifndef  XK_KP_Home
-# define XK_KP_Home	0xFF95
-#endif
-#ifndef  XK_KP_End
-# define XK_KP_End	0xFF9C
-#endif
-#ifndef  XK_KP_Left
-# define XK_KP_Left	0xFF96
-#endif
-#ifndef  XK_KP_Right
-# define XK_KP_Right	0xFF98
-#endif
-#ifndef  XK_KP_Begin
-# define XK_KP_Begin	0xFF9D
-#endif
-
 
 static const struct default_keycode_map apollo_map [] =
 {
