@@ -5,98 +5,6 @@
  * By Berthold Gunreben <gunreben@wvwx01.wifak.uni-wuerzburg.de>
  */
 
-#ifndef  XK_dead_ogonek
-# define XK_dead_ogonek		0xFE5C
-#endif
-#ifndef XK_3270_DeleteWord
-# define XK_3270_DeleteWord	0xFD1A
-#endif
-#ifndef XK_Greek_OMEGA
-# define XK_Greek_OMEGA		0x7d9
-#endif
-#ifndef XK_ISO_Left_Tab
-# define XK_ISO_Left_Tab	0xFE20
-#endif
-#ifndef XK_KP_Begin
-# define XK_KP_Begin		0xFF9D
-#endif
-#ifndef XK_KP_Delete
-# define XK_KP_Delete		0xFF9F
-#endif
-#ifndef XK_KP_Down
-# define XK_KP_Down		0xFF99
-#endif
-#ifndef XK_KP_End
-# define XK_KP_End		0xFF9C
-#endif
-#ifndef XK_KP_Home
-# define XK_KP_Home		0xFF95
-#endif
-#ifndef XK_KP_Insert
-# define XK_KP_Insert		0xFF9E
-#endif
-#ifndef XK_KP_Left
-# define XK_KP_Left		0xFF96
-#endif
-#ifndef XK_KP_Next
-# define XK_KP_Next		0xFF9B
-#endif
-#ifndef XK_KP_Prior
-# define XK_KP_Prior		0xFF9A
-#endif
-#ifndef XK_KP_Right
-# define XK_KP_Right		0xFF98
-#endif
-#ifndef XK_KP_Up
-# define XK_KP_Up		0xFF97
-#endif
-#ifndef XK_Pointer_EnableKeys
-# define XK_Pointer_EnableKeys	0xFEF9
-#endif
-#ifndef XK_dead_abovedot
-# define XK_dead_abovedot	0xFE56
-#endif
-#ifndef XK_dead_abovering
-# define XK_dead_abovering	0xFE58
-#endif
-#ifndef XK_dead_acute
-# define XK_dead_acute		0xFE51
-#endif
-#ifndef XK_dead_belowdot
-# define XK_dead_belowdot	0xFE60
-#endif
-#ifndef XK_dead_breve
-# define XK_dead_breve		0xFE55
-#endif
-#ifndef XK_dead_caron
-# define XK_dead_caron		0xFE5A
-#endif
-#ifndef XK_dead_cedilla
-# define XK_dead_cedilla	0xFE5B
-#endif
-#ifndef XK_dead_circumflex
-# define XK_dead_circumflex	0xFE52
-#endif
-#ifndef XK_dead_diaeresis
-# define XK_dead_diaeresis	0xFE57
-#endif
-#ifndef XK_dead_doubleacute
-# define XK_dead_doubleacute	0xFE59
-#endif
-#ifndef XK_dead_grave
-# define XK_dead_grave		0xFE50
-#endif
-#ifndef XK_dead_macron
-# define XK_dead_macron		0xFE54
-#endif
-#ifndef XK_dead_ogonek
-# define XK_dead_ogonek		0xFE5C
-#endif
-#ifndef XK_dead_tilde
-# define XK_dead_tilde		0xFE53
-#endif
-
-
 static const struct default_keycode_map chergo_de_map [] = {
   {   9, 0,		{ XK_Escape }},
   {  10, 0,		{ XK_1,	XK_exclam,
