@@ -7,19 +7,6 @@
  * By Barry Warsaw <bwarsaw@cnri.reston.va.us>
  */
 
-#ifndef  SunXK_F36
-# define SunXK_F36     0x1005FF10
-#endif
-#ifndef  SunXK_F37
-# define SunXK_F37     0x1005FF11
-#endif
-#ifndef  SunXK_Sys_Req
-# define SunXK_Sys_Req 0x1005FF60
-#endif
-#ifndef  XK_KP_Insert
-# define XK_KP_Insert	0xFF9E
-#endif
-
 static const struct default_keycode_map gw2kn_map [] = {
   {   8, 0,		{ XK_grave,	XK_asciitilde }},
   {   9, 0,		{ XK_1,	XK_exclam }},
