@@ -1,11 +1,11 @@
-/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1995, 1996
+/* xkeycaps, Copyright (c) 1991, 1992, 1993, 1995, 1996, 1999
  * Jamie Zawinski <jwz@jwz.org>
  *
  * This file describes the key surfaces of the HP 300, 400, and 700 series
  * keyboards (Svensk).  By Jorgen Jonsson <jjo@algonet.se>
  */
 
-static const struct key_strings hpitfsf_caps [] = {
+static const struct key_strings hpitfsv_caps [] = {
 
   /* Row 0 */
 
