@@ -6,16 +6,6 @@
  * By Dave Carrigan <dave@dave.iplenergy.com>.
  */
 
-#ifndef  SunXK_F36
-# define SunXK_F36     0x1005FF10
-#endif
-#ifndef  SunXK_F37
-# define SunXK_F37     0x1005FF11
-#endif
-#ifndef  SunXK_Sys_Req
-# define SunXK_Sys_Req 0x1005FF60
-#endif
-
 static const struct default_keycode_map openwin104_map [] = {
   {   8, 0,		{ XK_grave,	XK_asciitilde }},
   {   9, 0,		{ XK_1,	XK_exclam }},
