@@ -117,12 +117,12 @@ static const struct key_strings pc104_caps [] = {
   /* Row 6 */
 
   {"Ctrl", 0},
-  {"Windows", 0},
+  {"=/+/", 0},
   {"Alt", 0},
   {" ", 0},
   {"Alt", 0},
-  {"Windows", 0},
-  {"Menu", 0},
+  {"=/+/", 0},
+  {"##", 0},
   {"Ctrl", 0},
   {"LeftArrow", 0},
   {"DownArrow", 0},
