@@ -5,41 +5,6 @@
  * By Aleksandar Milivojevic <alex@srce.hr>.
  */
 
-#ifndef  XK_Sys_Req
-# define XK_Sys_Req	0xFF15
-#endif
-#ifndef  XK_KP_End
-# define XK_KP_End	0xFF9C
-#endif
-#ifndef  XK_KP_Left
-# define XK_KP_Left	0xFF96
-#endif
-#ifndef  XK_KP_Home
-# define XK_KP_Home	0xFF95
-#endif
-#ifndef  XK_KP_Insert
-# define XK_KP_Insert	0xFF9E
-#endif
-#ifndef  XK_KP_Delete
-# define XK_KP_Delete	0xFF9F
-#endif
-#ifndef  XK_KP_Down
-# define XK_KP_Down	0xFF99
-#endif
-#ifndef  XK_KP_Right
-# define XK_KP_Right	0xFF98
-#endif
-#ifndef  XK_KP_Up
-# define XK_KP_Up	0xFF97
-#endif
-#ifndef  XK_KP_Next
-# define XK_KP_Next	0xFF9B
-#endif
-#ifndef  XK_KP_Prior
-# define XK_KP_Prior	0xFF9A
-#endif
-
-
 static const struct default_keycode_map pcxal_map [] = {
   {   8, 0,		{ XK_Escape }},
   {   9, 0,		{ XK_F1 }},
