@@ -5,48 +5,6 @@
  *
  */
 
-
-#ifndef  SunXK_F36
-# define SunXK_F36     0x1005FF10
-#endif
-#ifndef  SunXK_F37
-# define SunXK_F37     0x1005FF11
-#endif
-#ifndef  SunXK_Props
-# define SunXK_Props   0x1005FF70
-#endif
-#ifndef  SunXK_Front
-# define SunXK_Front   0x1005FF71
-#endif
-#ifndef  SunXK_Copy
-# define SunXK_Copy    0x1005FF72
-#endif
-#ifndef  SunXK_Open
-# define SunXK_Open    0x1005FF73
-#endif
-#ifndef  SunXK_Paste
-# define SunXK_Paste   0x1005FF74
-#endif
-#ifndef  SunXK_Cut
-# define SunXK_Cut    0x1005FF75
-#endif
-
-#ifndef  SunXK_FA_Grave
-# define SunXK_FA_Grave         0x1005FF00
-#endif
-#ifndef  SunXK_FA_Acute
-# define SunXK_FA_Acute         0x1005FF03
-#endif
-#ifndef  SunXK_FA_Diaeresis
-# define SunXK_FA_Diaeresis     0x1005FF04
-#endif
-#ifndef  SunXK_FA_Circum
-# define SunXK_FA_Circum        0x1005FF01
-#endif
-#ifndef  SunXK_FA_Tilde
-# define SunXK_FA_Tilde         0x1005FF02
-#endif
-
 static const struct default_keycode_map sun4es_map [] = {
   {   8, 0,             { XK_Cancel,      0,
                         XK_F11 }},
