@@ -7,34 +7,6 @@
  * Andreas Schuch <schuch@physik.uni-kl.de>.
  */
 
-#ifndef  SunXK_F36
-# define SunXK_F36     0x1005FF10
-#endif
-#ifndef  SunXK_F37
-# define SunXK_F37     0x1005FF11
-#endif
-#ifndef  SunXK_Props
-# define SunXK_Props   0x1005FF70
-#endif
-#ifndef  SunXK_Front
-# define SunXK_Front   0x1005FF71
-#endif
-#ifndef  SunXK_Copy
-# define SunXK_Copy    0x1005FF72
-#endif
-#ifndef  SunXK_Open
-# define SunXK_Open    0x1005FF73
-#endif
-#ifndef  SunXK_Paste
-# define SunXK_Paste   0x1005FF74
-#endif
-#ifndef  SunXK_Cut
-# define SunXK_Cut     0x1005FF75
-#endif
-#ifndef  SunXK_Sys_Req
-# define SunXK_Sys_Req 0x1005FF60
-#endif
-
 static const struct default_keycode_map sun5de_ow_map [] = {
 
   /* these keys have keycodes but no keysyms in the default map */
