@@ -5,72 +5,6 @@
  * Spanish layout.  By anonymous.
  */
 
-#ifndef  SunXK_F36
-# define SunXK_F36     0x1005FF10
-#endif
-#ifndef  SunXK_F37
-# define SunXK_F37     0x1005FF11
-#endif
-#ifndef  SunXK_Props
-# define SunXK_Props   0x1005FF70
-#endif
-#ifndef  SunXK_Front
-# define SunXK_Front   0x1005FF71
-#endif
-#ifndef  SunXK_Copy
-# define SunXK_Copy    0x1005FF72
-#endif
-#ifndef  SunXK_Open
-# define SunXK_Open    0x1005FF73
-#endif
-#ifndef  SunXK_Paste
-# define SunXK_Paste   0x1005FF74
-#endif
-#ifndef  SunXK_Cut
-# define SunXK_Cut     0x1005FF75
-#endif
-#ifndef  SunXK_Sys_Req
-# define SunXK_Sys_Req 0x1005FF60
-#endif
-
-#ifndef SunXK_PowerSwitch		/* New with R6 */
-# define SunXK_PowerSwitch		0x1005FF76
-#endif
-#ifndef  SunXK_AudioLowerVolume
-# define SunXK_AudioLowerVolume		0x1005FF77
-#endif
-#ifndef  SunXK_AudioMute
-# define SunXK_AudioMute		0x1005FF78
-#endif
-#ifndef  SunXK_AudioRaiseVolume
-# define SunXK_AudioRaiseVolume		0x1005FF79
-#endif
-#ifndef  SunXK_VideoDegauss
-# define SunXK_VideoDegauss		0x1005FF7A
-#endif
-#ifndef  SunXK_VideoLowerBrightness
-# define SunXK_VideoLowerBrightness	0x1005FF7B
-#endif
-#ifndef  SunXK_VideoRaiseBrightness
-# define SunXK_VideoRaiseBrightness	0x1005FF7C
-#endif
-#ifndef  SunXK_PowerSwitchShift
-# define SunXK_PowerSwitchShift		0x1005FF7D
-#endif
-
-#ifndef  SunXK_FA_Grave
-# define SunXK_FA_Grave         0x1005FF00
-#endif
-#ifndef  SunXK_FA_Acute
-# define SunXK_FA_Acute         0x1005FF03
-#endif
-#ifndef  SunXK_FA_Diaeresis
-# define SunXK_FA_Diaeresis     0x1005FF04
-#endif
-#ifndef  SunXK_FA_Circum
-# define SunXK_FA_Circum        0x1005FF01
-#endif
-
 static const struct default_keycode_map sun5es_ow_map [] = {
   {   8, 0,		{ XK_F11,	XK_F11,
 			XK_Cancel }},
