@@ -8,13 +8,6 @@
  * with Tektronix XP338 Version 6.0 Level 0.
  */
 
-#ifndef  TekXK_Remove
-# define TekXK_Remove	0x1000FF00
-#endif
-#ifndef  TekXK_Setup
-# define TekXK_Setup	0x1000FF12
-#endif
-
 static const struct default_keycode_map tek200xesc_us_map [] = {
   {  15, 0,		{ XK_F1,	XK_Pause }},
   {  16, 0,		{ XK_KP_F1 }},
