@@ -5,23 +5,6 @@
  * By Kristian Ejvind (Kristian.Ejvind@sth.frontec.se)
  */
 
-/* Taken from TEKkeysym.h, in XP software distribution */
-#ifndef  TekXK_Remove
-# define TekXK_Remove	0x1000FF00
-#endif
-#ifndef  TekXK_Hold
-# define TekXK_Hold	0x1000FF10
-#endif
-#ifndef  TekXK_Copy
-# define TekXK_Copy	0x1000FF11
-#endif
-#ifndef  TekXK_Setup
-# define TekXK_Setup	0x1000FF12
-#endif
-#ifndef  TekXK_Tek
-# define TekXK_Tek	0x1000FFFF
-#endif
-
 static const struct default_keycode_map tekxn10_sf_map [] = {
   {   9, 0,		{ XK_Escape,	XK_Escape }},
   {  10, 0,		{ XK_asciitilde,	XK_degree }},
