@@ -6,10 +6,6 @@
  * By Joe Siegrist <iniquity@cs.UMD.EDU>.
  */
 
-#ifndef  XK_Sys_Req
-# define XK_Sys_Req	0xFF15
-#endif
-
 static const struct default_keycode_map xinside_map [] = {
   {   9, 0,		{ XK_Escape }},
   {  10, 0,		{ XK_1,	XK_exclam }},
@@ -96,6 +92,7 @@ static const struct default_keycode_map xinside_map [] = {
   {  91, 0,		{ XK_KP_Decimal }},
   {  92, 0,		{ XK_Print }},
   {  93, 0,		{ XK_Down }},
+  {  94, 0,		{ XK_backslash,	XK_bar }},
   {  95, 0,		{ XK_F11 }},
   {  96, 0,		{ XK_F12 }},
   { 118, 0,		{ XK_Left }},
